Coverage for arrakis/__init__.py: 80.0%

1# Copyright (c) 2022, California Institute of Technology and contributors

2#

3# You should have received a copy of the licensing terms for this

4# software included in the file "LICENSE" located in the top-level

5# directory of this package. If you did not, you can view a copy at

6# https://git.ligo.org/ngdd/arrakis-python/-/raw/main/LICENSE

7

8 try:

9 from ._version import version as __version__

10 except ModuleNotFoundError:

11 import setuptools_scm

12

13 __version__ = setuptools_scm.get_version(fallback_version="?.?.?")

14

15 from .api import count as count

16 from .api import describe as describe

17 from .api import fetch as fetch

18 from .api import find as find

19 from .api import stream as stream

20 from .block import SeriesBlock as SeriesBlock

21 from .block import Time as Time

22 from .channel import Channel as Channel

23 from .client import Client as Client

24 from .publish import Publisher as Publisher